/// @example SimpleStructuredLightScanner.cpp
///
/// Shows usage of calibration with the StructuredLightScanner class.

#include "davidSDK/david.h"

namespace examples {


/// Shows usage of calibration with the StructuredLightScanner class.
/// Simple example class for usage of StructuredLightScanner class via david::Client::sls interface.
void main_SimpleCalibration()
{
	try
	{
		// Connection to DAVID server is established within constructor.
		// david::Client::Disconnect is automatically called in destructor of david::Client.
		david::Client david;
		david.Connect();

		// Select screen and camera.
		david.sls().SetScreenID(3);
		david.sls().SelectCamera("DAVID-CAM-3-M (8F6DEE1E)"); 

		// Tells DAVID server to calibrate, and save calibration parameters to .cal files.
		david.sls().Calibrate(120.0);
		david.sls().ExportCalibration("camera.cal", "projector.cal");
		
		// Re-import calibration (this step is not necessary here, it is just for demonstration/testing):
		david.sls().ImportCalibration("camera.cal", "projector.cal");
		
		// david::Client::Disconnect is automatically called in destructor of david::Client
		// at the end of this { } block
	}
	catch (david::Exception& e)
	{
		e.PrintError();
	}
}


} // namespace examples
